/*
    ios.java by Frank B. Brokken (f.b.brokken@rc.rug.nl), June 2001
    Distribution: GPL

    Since all local  developments are stored in the package local,
    there is no need for further Dutch names. 

    To avoid unly language combinations, I now switch to English as the
    primary language.

    -----------------------------

    class ios is the base package for all I/O operations.

    ios is intended to be used as a base class for derivation, hence its 
    access rights are not public.

    ios defines the following members:

    Bookkeeping:

    boolean eof()       - returns true if EOF was sensed
    boolean fail()      - returns true if something failed.
    void clear()        - clears a failure state, needed, e.g., 
                            to reset a stream after a read-failure.
    String message()    - returns the error message corresponding to the 
                            latest fail() state, undefined otherwise
*/

package local.ios;

import java.lang.String;

public class ios
{
    public boolean fail()       // true: stream unusable for some reason
    {
        return !good;
    }

    public boolean eof()        // true: stream at EOF
    {
        return atEof;
    }

    public void clear()         // resets all flags, might be undone at the
    {                           // next operation, though.
        atEof = false;
        good = true;
    }

    public String message()     // returns messsage corresponding to latest
    {                           // fail-state
        return msg;
    }

    // ******** Protected       
    
    protected void setMsg(Exception e)  // set a message from an exception
    {                                   // set state to fail()
        good = false;
        msg = e.toString();
    }
    
    protected void setMsg(String errMess) // set message from a string
    {
        good = false;
        msg = errMess;
    }
    
    protected void setEof()             // set Eof state
    {
        atEof = true;
        good = false;
        msg = "EOF reached";
    }

    protected void setEof(Exception e)  // set Eof state from an Exception
    {
        atEof = true;
        setMsg(e);
    }

    protected boolean   good        = true;

    // ********* Private
    
    private boolean     atEof = false;
    private String      msg = "";
}
   

